@@ -85,6 +85,7 @@ typedef struct {
     guint summary_remember_tab;
 
     gint panel_size;
+    gint icon_size;
     guint panel_rows;
     XfcePanelPluginMode panel_orientation;
     gboolean single_row;
@@ -114,6 +115,7 @@ typedef struct {
     gchar *lon;
     gint msl;
     gchar *timezone;
+    gchar *offset;
     gchar *timezone_initial;
     gint cache_file_max_age;
     gboolean night_time;
@@ -144,6 +146,8 @@ gchar *get_cache_directory(void);
 
 void update_timezone(plugin_data *data);
 
+void update_offset(plugin_data *data);
+
 void update_icon(plugin_data *data);
 
 void update_scrollbox(plugin_data *data,
